@@ -44,6 +44,9 @@ from .RepositoryBaseClass import RepositoryBaseClass, RepositoryValidationExcept
 from .RepositoryCachingBaseClass import RepositoryCachingBaseClass
 from .RepositoryObjBaseClass import RepositoryObjBaseClass
 
+#MultiTenant OBject Store
+from .MultiTenantObjectStore import InvalidTenantNameException, MultiTenantObjectStore
+
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
